@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Type, _GenericAlias  # type: ignore
+from typing import Any, Dict, List, Type
 
 from blocks.types import Block, Event
 
@@ -17,8 +17,9 @@ def get_input_events_type(block: Block) -> List[Type[Event]]:
     if len(annots) == 0:
         return []
     input_type = list(annots.values())[0]
-    if isinstance(input_type, _GenericAlias):
-        return list(input_type.__args__)
+    generic_args = getattr(input_type, '__args__', None)
+    if generic_args is not None:
+        return list(generic_args)
     return [input_type]
 
 
@@ -28,10 +29,10 @@ def get_output_events_type(block: Block) -> List[Type[Event]]:
     result = []
     while annotations_to_flatten:
         annotation = annotations_to_flatten.pop(0)
-        if annotation is None:
-            continue
-        if isinstance(annotation, _GenericAlias):
-            annotations_to_flatten.extend(list(annotation.__args__))
-        else:
-            result.append(annotation)
+        if annotation is not None:
+            generic_args = getattr(annotation, '__args__', None)
+            if generic_args is not None:
+                annotations_to_flatten.extend(list(generic_args))
+            else:
+                result.append(annotation)
     return result
